
.. _l-issues-todolist:

Bugs and improvments
====================

.. index:: issues, todo

.. contents::

Bugs
++++

.. todoextlist::
    :tag: bug

Improvments
+++++++++++

.. todoextlist::
    :tag: plus
